#!/usr/bin/env node

const fs = require('fs');
const path = require('path');

const projectName = process.argv[2];

if (!projectName) {
  console.error('❌ Please provide a project name: node-boilerplate my-app');
  process.exit(1);
}

const root = path.join(process.cwd(), projectName);

const folders = [
  'config',
  'controllers',
  'models',
  'routes',
  'middleware',
  'utils',
  'logs',
  'public'
];

const files = [
  '.env',
  '.gitignore',
  'server.js',
  'package.json',
  'README.md'
];

console.log(`🚀 Creating Node.js boilerplate at ${root}`);

// Create root
fs.mkdirSync(root);

// Create folders
folders.forEach(folder => {
  fs.mkdirSync(path.join(root, folder), { recursive: true });
});

// Create files
files.forEach(file => {
  fs.writeFileSync(path.join(root, file), '');
});

// Add basic README.md
fs.writeFileSync(path.join(root, 'README.md'), `# ${projectName}\n\nGenerated by node-boilerplate CLI.`);

console.log('✅ Boilerplate generated successfully!');
